# inspired from: https://github.com/explosion/spaCy/blob/master/spacy/about.py

__title__ = "access_niu"
__version__ = "0.0.1"
__summary__ = "Production grade Natural Image Understanding"
__uri__ = "http://accessai.co"
__author__ = "ConvexHull Technology"
__email__ = "contact@accessai.co"
__license__ = "Apache 2.0"
__release__ = True
